/* XQF - Quake server browser and launcher
 * Copyright (C) 1998 Roman Pozlevich <roma@botik.ru>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 */

#ifndef __FILTER_H__
#define __FILTER_H__

#include <gtk/gtk.h>


typedef int (*filterfunc) (struct server *);


struct filter {
  char	*name;
  GSList *servers;
  int	built;
  filterfunc func;
  GtkWidget *widget;
};


extern	void build_filtered_list (struct filter *f, struct master *m);
extern	int filter_add_server (struct filter *f, struct server *s);

extern	void free_filter_data (struct filter *f);
extern	void free_filters_data (void);

extern  struct filter filters[];
extern 	struct filter *cur_filter;


#endif /* __FILTER_H__ */

